{"": "", "< Back": "", "Access": "\uc5d1\uc138\uc2a4", "All": "\uc804\uccb4", "Apply": "\uc801\uc6a9", "Cancel": "\ucde8\uc18c", "Change permissions": "\uad8c\ud55c \ubcc0\uacbd", "Clipboard": "\ud074\ub9bd\ubcf4\ub4dc", "Close": "\ub2eb\uae30", "Copy": "\ubcf5\uc0ac", "Create": "\uc0dd\uc131", "Cut": "\uc798\ub77c\ub0b4\uae30", "DIRECTORY": "\ud3f4\ub354", "Delete": "\uc0ad\uc81c", "Directory name": "\ud3f4\ub354 \uc774\ub984", "EXECUTE": "\uc2e4\ud589", "Edit in Notepad": "\uba54\ubaa8\uc7a5\uc5d0\uc11c \ud3b8\uc9d1", "Extra": "\uae30\ud0c0", "FILE": "\ud30c\uc77c", "File name": "\ud30c\uc77c \uc774\ub984", "Full path": "\uc804\uccb4 \uacbd\ub85c", "Group": "\uadf8\ub8f9", "LINK": "\ub9c1\ud06c", "Mode": "\ubaa8\ub4dc", "Modified": "\ubcc0\uacbd\ub428", "Name": "\uc774\ub984", "New directory": "\uc0c8 \ud3f4\ub354", "New file": "\uc0c8 \ud30c\uc77c", "Owner": "\uc18c\uc720\uc790", "Paste here": "\uc5ec\uae30\uc5d0 \ubd99\uc5ec\ub123\uc73c\uc138\uc694.", "Permission bits": "", "READ": "\uc77d\uae30", "Remove": "\uc0ad\uc81c", "Remove all items": "\uc804\uccb4 \uc0ad\uc81c", "Root directory": "", "Show in Notepad": "", "Size": "\ud06c\uae30", "Tab": "\ud0ed", "Type": "\ud0c0\uc785", "Upload": "\uc5c5\ub85c\ub4dc", "Uploading ...": "", "User": "\uc0ac\uc6a9\uc790", "WRITE": "\uc4f0\uae30", "items selected": "\uc120\ud0dd\ub41c \ud56d\ubaa9", "File Manager": "\ud30c\uc77c \uad00\ub9ac\uc790", "Could not read file information": "", "File mode saved": "", "Could not load directory": "", "Delete selected items?": "", "Could not create file": "", "Could not create directory": "\ud3f4\ub354\ub97c \uc0dd\uc131\ud560 \uc218 \uc5c6\uc2b5\ub2c8\ub2e4", "Uploaded": "\uc5c5\ub85c\ub4dc \ub428"}