{"": "", "< Back": "", "Access": "Acces", "All": "Toate", "Apply": "Aplicare", "Cancel": "Anulare", "Change permissions": "Schimbare permisiuni", "Clipboard": "Clipboard", "Close": "\u00cenchide", "Copy": "Copiere", "Create": "Creare", "Cut": "Decupare", "DIRECTORY": "DIRECTOR", "Delete": "\u0218tergere", "Directory name": "Nume director", "EXECUTE": "EXECUTARE", "Edit in Notepad": "Editeaz\u0103 \u00een Notepad", "Extra": "Extra", "FILE": "FI\u0218IER", "File name": "Nume fi\u0219ier", "Full path": "Calea complet\u0103", "Group": "Grup", "LINK": "LINK", "Mode": "Mod", "Modified": "Modificat", "Name": "Nume", "New directory": "Director nou", "New file": "Fi\u0219ier nou", "Owner": "Proprietar", "Paste here": "Lipi\u021bi aici", "Permission bits": "Bi\u021bi de permisiuni", "READ": "CITIRE", "Remove": "Eliminare", "Remove all items": "Elimina\u021bi toate elementele", "Root directory": "", "Show in Notepad": "Arat\u0103 \u00een Notepad", "Size": "Dimensiune", "Tab": "Fil\u0103", "Type": "Tip", "Upload": "\u00cenc\u0103rcare", "Uploading ...": "Se \u00eencarc\u0103 ...", "User": "Utilizator", "WRITE": "SCRIERE", "items selected": "elemente selectate", "File Manager": "Gestionare fi\u0219iere", "Could not read file information": "Nu s-au putut citi informa\u021biile fi\u0219ierului", "File mode saved": "Mod fi\u0219ier salvat", "Could not load directory": "Directorul nu a putut fi \u00eenc\u0103rcat", "Delete selected items?": "\u0218terge\u021bi elementele selectate?", "Could not create file": "Nu s-a putut crea fi\u0219ierul", "Could not create directory": "Directorul nu a putut fi creat", "Uploaded": "\u00cenc\u0103rcat"}