{"": "", "< Back": "< Indietro", "Access": "Accesso", "All": "Tutto", "Apply": "Applica", "Cancel": "Annulla", "Change permissions": "Modifica le autorizzazioni", "Clipboard": "Appunti", "Close": "Chiudi", "Copy": "Copia", "Create": "Crea", "Cut": "Taglia", "DIRECTORY": "CARTELLA", "Delete": "Elimina", "Directory name": "Nome della cartella", "EXECUTE": "ESEGUI", "Edit in Notepad": "Modificare in blocco note", "Extra": "Extra", "FILE": "FILE", "File name": "Nome file", "Full path": "Percorso completo", "Group": "Gruppo", "LINK": "COLLEGAMENTO", "Mode": "Modalit\u00e0", "Modified": "Modificato", "Name": "Nome", "New directory": "Nuova Cartella", "New file": "Nuovo file", "Owner": "Proprietario", "Paste here": "Incolla qui", "Permission bits": "Bit di autorizzazione", "READ": "LEGGI", "Remove": "Rimuovi", "Remove all items": "Rimuovi tutti gli elementi", "Root directory": "Cartella di root", "Show in Notepad": "Mostra nel Blocco Note", "Size": "Dimensione", "Tab": "Scheda", "Type": "Tipo", "Upload": "Carica", "Uploading ...": "Caricamento...", "User": "Utente", "WRITE": "SCRIVI", "items selected": "elementi selezionati", "File Manager": "Gestione file", "Could not read file information": "Non \u00e8 possibile leggere le informazioni del file", "File mode saved": "Modalit\u00e0 file salvato", "Could not load directory": "Impossibile caricare la cartella", "Delete selected items?": "Eliminare gli elementi selezionati?", "Could not create file": "Impossibile creare il file", "Could not create directory": "Impossibile creare la cartella", "Uploaded": "File caricato"}