{"": "", "< Back": "", "Access": "Tagong", "All": "", "Apply": "Tapasse", "Cancel": "Annulearje", "Change permissions": "", "Clipboard": "Klamboerd", "Close": "Slute", "Copy": "Kopiearje", "Create": "Meitsje", "Cut": "", "DIRECTORY": "", "Delete": "", "Directory name": "", "EXECUTE": "", "Edit in Notepad": "", "Extra": "", "FILE": "", "File name": "", "Full path": "", "Group": "Groep", "LINK": "", "Mode": "", "Modified": "", "Name": "Namme", "New directory": "", "New file": "", "Owner": "", "Paste here": "", "Permission bits": "", "READ": "", "Remove": "", "Remove all items": "", "Root directory": "", "Show in Notepad": "", "Size": "Grutte", "Tab": "", "Type": "Type", "Upload": "", "Uploading ...": "", "User": "Br\u00fbker", "WRITE": "", "items selected": "", "File Manager": "", "Could not read file information": "", "File mode saved": "", "Could not load directory": "", "Delete selected items?": "", "Could not create file": "", "Could not create directory": "", "Uploaded": ""}