{"": "", "< Back": "", "Access": "Eri\u015fim", "All": "Hepsi", "Apply": "Uygula", "Cancel": "\u0130ptal", "Change permissions": "\u0130zinleri de\u011fi\u015ftir", "Clipboard": "Pano", "Close": "Kapat", "Copy": "Kopyala", "Create": "Olu\u015ftur", "Cut": "Kes", "DIRECTORY": "D\u0130Z\u0130N", "Delete": "Sil", "Directory name": "Dizin ad\u0131", "EXECUTE": "\u00c7ALI\u015eTIR", "Edit in Notepad": "Not Defteri'nde d\u00fczenle", "Extra": "Ekstra", "FILE": "DOSYA", "File name": "Dosya ad\u0131", "Full path": "Tam Yol", "Group": "Grup", "LINK": "BA\u011eLANTI", "Mode": "Mod", "Modified": "De\u011fi\u015ftirilme", "Name": "Ad\u0131", "New directory": "Yeni Klas\u00f6r", "New file": "Yeni Dosya", "Owner": "Sahibi", "Paste here": "Buraya yap\u0131\u015ft\u0131r", "Permission bits": "\u0130zin bitleri", "READ": "OKU", "Remove": "Kald\u0131r", "Remove all items": "T\u00fcm \u00f6\u011feleri kald\u0131r", "Root directory": "", "Show in Notepad": "", "Size": "Boyut", "Tab": "Tab", "Type": "T\u00fcr\u00fc", "Upload": "Y\u00fckle", "Uploading ...": "Y\u00fckleniyor ...", "User": "Kullan\u0131c\u0131", "WRITE": "YAZ", "items selected": "\u00f6\u011fe se\u00e7ildi", "File Manager": "Dosya Y\u00f6neticisi", "Could not read file information": "Dosya bilgisi okunam\u0131yor", "File mode saved": "Dosya modu kaydedildi", "Could not load directory": "Dizin y\u00fcklenemedi", "Delete selected items?": "Se\u00e7ili \u00f6\u011feler silinsin mi?", "Could not create file": "Dosya olu\u015fturulamad\u0131", "Could not create directory": "Dizin olu\u015fturulamad\u0131", "Uploaded": "Y\u00fcklendi"}