{"": "", "< Back": "", "Access": "Pr\u00edstup", "All": "V\u0161etko", "Apply": "Pou\u017ei\u0165", "Cancel": "Zru\u0161i\u0165", "Change permissions": "", "Clipboard": "", "Close": "Zatvori\u0165", "Copy": "Kop\u00edrova\u0165", "Create": "Vytvori\u0165", "Cut": "Vystrihn\u00fa\u0165", "DIRECTORY": "ADRES\u00c1R", "Delete": "Odstr\u00e1ni\u0165", "Directory name": "N\u00e1zov adres\u00e1ra", "EXECUTE": "SPUSTI\u0164", "Edit in Notepad": "Upravi\u0165 v programe Pozn\u00e1mkov\u00fd blok", "Extra": "Extra", "FILE": "S\u00daBOR", "File name": "N\u00e1zov s\u00faboru", "Full path": "", "Group": "Skupina", "LINK": "ODKAZ", "Mode": "", "Modified": "Upraven\u00e9", "Name": "Meno", "New directory": "Nov\u00fd adres\u00e1r", "New file": "Nov\u00fd s\u00fabor", "Owner": "Vlastn\u00edk", "Paste here": "", "Permission bits": "", "READ": "", "Remove": "Odstr\u00e1ni\u0165", "Remove all items": "Odstr\u00e1ni\u0165 v\u0161etky polo\u017eky", "Root directory": "", "Show in Notepad": "", "Size": "Ve\u013ekos\u0165", "Tab": "", "Type": "Typ", "Upload": "Nahra\u0165", "Uploading ...": "", "User": "Pou\u017e\u00edvate\u013e", "WRITE": "P\u00cdSA\u0164", "items selected": "vybrat\u00e9 polo\u017eky", "File Manager": "Spr\u00e1vca s\u00faborov", "Could not read file information": "", "File mode saved": "", "Could not load directory": "", "Delete selected items?": "", "Could not create file": "", "Could not create directory": "", "Uploaded": ""}