{"": "", "< Back": "", "Access": "Pristup", "All": "Sve", "Apply": "Primeni", "Cancel": "Otka\u017ei", "Change permissions": "Izmeni dozvole", "Clipboard": "Clipboard", "Close": "Zatvori", "Copy": "Kopiraj", "Create": "Kreiraj", "Cut": "Iseci", "DIRECTORY": "Direktorijum", "Delete": "Obri\u0161i", "Directory name": "Naziv direktorijuma", "EXECUTE": "Uni\u0161ti", "Edit in Notepad": "Izmeni u Notepadu", "Extra": "Dodatno", "FILE": "Fajl", "File name": "Ime fajla", "Full path": "Potpuna putanja", "Group": "Grupa", "LINK": "Link", "Mode": "Re\u017eim", "Modified": "Izmenjeno", "Name": "Ime", "New directory": "Novi direktorijum", "New file": "Nova datoteka", "Owner": "Vlasnik", "Paste here": "Zalepi ovde", "Permission bits": "Dozvole", "READ": "", "Remove": "Ukloni", "Remove all items": "Ukloni sve stavke", "Root directory": "", "Show in Notepad": "", "Size": "", "Tab": "", "Type": "", "Upload": "Uploaduj", "Uploading ...": "", "User": "Korisnik", "WRITE": "", "items selected": "stavki selektovano", "File Manager": "Menadzer Datoteka", "Could not read file information": "", "File mode saved": "", "Could not load directory": "", "Delete selected items?": "", "Could not create file": "", "Could not create directory": "", "Uploaded": ""}