{"": "", "< Back": "", "Access": "Akses", "All": "Semua", "Apply": "Terapkan", "Cancel": "Batal", "Change permissions": "Mengubah izin", "Clipboard": "Clipboard", "Close": "Tutup", "Copy": "Salin", "Create": "Buat", "Cut": "Potong", "DIRECTORY": "DIREKTORI", "Delete": "Hapus", "Directory name": "Nama direktori", "EXECUTE": "MENJALANKAN", "Edit in Notepad": "Menyunting di Notepad", "Extra": "Tambahan", "FILE": "BERKAS", "File name": "Nama berkas", "Full path": "Path lengkap", "Group": "Grup", "LINK": "LINK", "Mode": "Mode", "Modified": "Dimodifikasi", "Name": "Nama", "New directory": "Direktori baru", "New file": "File baru", "Owner": "Pemilik", "Paste here": "Tempel di sini", "Permission bits": "Hak akses", "READ": "MEMBACA", "Remove": "Hapus", "Remove all items": "Menghapus semua item", "Root directory": "", "Show in Notepad": "", "Size": "Ukuran", "Tab": "Tab", "Type": "Tipe", "Upload": "Unggah", "Uploading ...": "", "User": "Pengguna", "WRITE": "MENULIS", "items selected": "item yang dipilih", "File Manager": "Manajer berkas", "Could not read file information": "", "File mode saved": "", "Could not load directory": "", "Delete selected items?": "", "Could not create file": "", "Could not create directory": "", "Uploaded": ""}