{"": "", "< Back": "< Zur\u00fcck", "Access": "Zugriff", "All": "Alle", "Apply": "Anwenden", "Cancel": "Abbrechen", "Change permissions": "\u00c4ndere Brechtigungen", "Clipboard": "Zwischenablage", "Close": "Schlie\u00dfen", "Copy": "Kopieren", "Create": "Erstellen", "Cut": "Ausschneiden", "DIRECTORY": "VERZEICHNIS", "Delete": "L\u00f6schen", "Directory name": "Verzeichnisname", "EXECUTE": "AUSF\u00dcHREN", "Edit in Notepad": "Im Editor bearbeiten", "Extra": "Extra", "FILE": "Datei", "File name": "Dateiname", "Full path": "Vollst\u00e4ndigen Pfad", "Group": "Gruppe", "LINK": "Link", "Mode": "Modus", "Modified": "Ge\u00e4ndert", "Name": "Name", "New directory": "Neues Verzeichnis", "New file": "Neue Datei", "Owner": "Besitzer\t", "Paste here": "F\u00fcge hier ein", "Permission bits": "Berechtigungsbits", "READ": "LESEN", "Remove": "Entfernen", "Remove all items": "Entferne alle Elemente", "Root directory": "Root-Verzeichnis", "Show in Notepad": "Im Notizblock anzeigen", "Size": "Gr\u00f6\u00dfe", "Tab": "Tab", "Type": "Typ", "Upload": "Hochladen", "Uploading ...": "Lade hoch...", "User": "Benutzer", "WRITE": "SCHREIBEN", "items selected": "ausgew\u00e4hlten Elemente", "File Manager": "Datei-Manager", "Could not read file information": "Dateiinformationen konnten nicht gelesen werden", "File mode saved": "Datei-Modus gespeichert", "Could not load directory": "Verzeichnis konnte nicht geladen werden", "Delete selected items?": "Ausgew\u00e4hlte Elemente l\u00f6schen?", "Could not create file": "Datei konnte nicht erstellt werden", "Could not create directory": "Verzeichnis konnte nicht erstellt werden", "Uploaded": "Hochgeladen"}