{"": "", "< Back": "", "Access": "Dostop", "All": "Vse", "Apply": "Uporabi", "Cancel": "Prekli\u010di", "Change permissions": "Spremeni dovoljenja", "Clipboard": "Odlo\u017ei\u0161\u010de", "Close": "Zapri", "Copy": "Kopiraj", "Create": "Ustvari", "Cut": "Izre\u017ei", "DIRECTORY": "IMENIK", "Delete": "Izbri\u0161i", "Directory name": "Ime imenika", "EXECUTE": "Izvr\u0161iti", "Edit in Notepad": "Uredi v Bele\u017enici", "Extra": "Dodatno", "FILE": "DATOTEKA", "File name": "Ime datoteke", "Full path": "Celotna pot", "Group": "Skupina", "LINK": "POVEZAVA", "Mode": "Na\u010din", "Modified": "Spremenjeno", "Name": "Ime", "New directory": "Nova mapa", "New file": "Nova datoteka", "Owner": "Lastnik", "Paste here": "Prilepi tukaj", "Permission bits": "", "READ": "BRANJE", "Remove": "Odstrani", "Remove all items": "Odstrani vse elemente", "Root directory": "", "Show in Notepad": "", "Size": "Velikost", "Tab": "Tab", "Type": "Vrsta", "Upload": "Nalo\u017ei", "Uploading ...": "", "User": "Uporabnik", "WRITE": "PISANJE", "items selected": "izbrani elementi", "File Manager": "Raziskovalec", "Could not read file information": "", "File mode saved": "", "Could not load directory": "", "Delete selected items?": "", "Could not create file": "", "Could not create directory": "", "Uploaded": ""}