{"": "", "< Back": "", "Access": "", "All": "Toct", "Apply": "", "Cancel": "Ni\u00feili\u00e7arh", "Change permissions": "", "Clipboard": "", "Close": "Fermarh", "Copy": "Copiarh", "Create": "", "Cut": "Entaglharh", "DIRECTORY": "", "Delete": "Zeletarh", "Directory name": "", "EXECUTE": "", "Edit in Notepad": "", "Extra": "", "FILE": "FISCHEIR", "File name": "N\u00f3mina del fischeir", "Full path": "", "Group": "", "LINK": "", "Mode": "", "Modified": "", "Name": "N\u00f3mina", "New directory": "", "New file": "", "Owner": "", "Paste here": "", "Permission bits": "", "READ": "", "Remove": "Removarh", "Remove all items": "", "Root directory": "", "Show in Notepad": "", "Size": "", "Tab": "", "Type": "", "Upload": "", "Uploading ...": "", "User": "", "WRITE": "", "items selected": "", "File Manager": "", "Could not read file information": "", "File mode saved": "", "Could not load directory": "", "Delete selected items?": "", "Could not create file": "", "Could not create directory": "", "Uploaded": ""}