{"": "", "< Back": "", "Access": "", "All": "", "Apply": "", "Cancel": "Nuligi", "Change permissions": "\u015can\u011di permesojn", "Clipboard": "", "Close": "Fermi", "Copy": "Kopii", "Create": "Krei", "Cut": "Eltondi", "DIRECTORY": "DOSIERUJO", "Delete": "Forigi", "Directory name": "", "EXECUTE": "", "Edit in Notepad": "", "Extra": "", "FILE": "DOSIERO", "File name": "Dosiernomo", "Full path": "", "Group": "Grupo", "LINK": "", "Mode": "", "Modified": "\u015can\u011dita", "Name": "Nomo", "New directory": "Nova dosierujo", "New file": "Nova dosiero", "Owner": "Posedanto", "Paste here": "", "Permission bits": "", "READ": "", "Remove": "Forigi", "Remove all items": "", "Root directory": "", "Show in Notepad": "", "Size": "", "Tab": "Langeto", "Type": "", "Upload": "Al\u015duti", "Uploading ...": "", "User": "Uzanto", "WRITE": "", "items selected": "", "File Manager": "", "Could not read file information": "", "File mode saved": "", "Could not load directory": "", "Delete selected items?": "", "Could not create file": "", "Could not create directory": "", "Uploaded": ""}