{"": "", "< Back": "< Tillbaka", "Access": "Tillg\u00e5ng", "All": "Alla", "Apply": "Verkst\u00e4ll", "Cancel": "Avbryt", "Change permissions": "\u00c4ndra beh\u00f6righet", "Clipboard": "Urklipp", "Close": "St\u00e4ng", "Copy": "Kopiera", "Create": "Skapa", "Cut": "Klipp ut", "DIRECTORY": "KATALOG", "Delete": "Ta bort", "Directory name": "Katalogens namn", "EXECUTE": "UTF\u00d6R", "Edit in Notepad": "Redigera i Anteckningar", "Extra": "Extra", "FILE": "FIL", "File name": "Filnamn", "Full path": "Fullst\u00e4ndig s\u00f6kv\u00e4g", "Group": "Grupp", "LINK": "L\u00c4NK", "Mode": "L\u00e4ge", "Modified": "\u00c4ndrad", "Name": "Namn", "New directory": "Ny mapp", "New file": "Ny fil", "Owner": "\u00c4gare", "Paste here": "Klistra in", "Permission bits": "Beh\u00f6righeter", "READ": "L\u00c4S", "Remove": "Ta bort", "Remove all items": "Ta bort alla objekt", "Root directory": "Rotkatalog", "Show in Notepad": "Visa i Anteckningar", "Size": "Storlek", "Tab": "Fliken", "Type": "Typ", "Upload": "Ladda upp", "Uploading ...": "Laddar upp...", "User": "Anv\u00e4ndare", "WRITE": "SKRIV", "items selected": "markerade objekt", "File Manager": "Filhanterare", "Could not read file information": "Kunde inte l\u00e4sa filinformation", "File mode saved": "Fill\u00e4ge sparat", "Could not load directory": "Kunde inte ladda katalog", "Delete selected items?": "Ta bort markerade f\u00f6rem\u00e5l?", "Could not create file": "Kunde inte skapa fil", "Could not create directory": "Kunde inte skapa katalog", "Uploaded": "Uppladdad"}