{"": "", "< Back": "< Retour", "Access": "Acc\u00e8s", "All": "Tous", "Apply": "Appliquer", "Cancel": "Annuler", "Change permissions": "Modifier les autorisations", "Clipboard": "Presse-papiers", "Close": "Fermer", "Copy": "Copier", "Create": "Cr\u00e9er", "Cut": "Couper", "DIRECTORY": "REPERTOIRE", "Delete": "Supprimer", "Directory name": "Nom du r\u00e9pertoire", "EXECUTE": "EX\u00c9CUTER", "Edit in Notepad": "Modifier dans le bloc-notes", "Extra": "Extra", "FILE": "FICHIER", "File name": "Nom du fichier", "Full path": "Chemin d'acc\u00e8s complet", "Group": "Groupe", "LINK": "LIEN", "Mode": "Mode", "Modified": "Modifi\u00e9", "Name": "Nom", "New directory": "Nouveau r\u00e9pertoire", "New file": "Nouveau fichier", "Owner": "Propri\u00e9taire", "Paste here": "Coller ici", "Permission bits": "Bits de Permissions", "READ": "LIRE", "Remove": "Supprimer", "Remove all items": "Supprimer tous les \u00e9l\u00e9ments", "Root directory": "R\u00e9pertoire racine", "Show in Notepad": "Afficher dans le bloc-notes", "Size": "Taille", "Tab": "Onglet", "Type": "Type", "Upload": "Envoyer", "Uploading ...": "Envoi en cours...", "User": "Utilisateur", "WRITE": "\u00c9CRIRE", "items selected": "\u00e9l\u00e9ments s\u00e9lectionn\u00e9s", "File Manager": "Gestionnaire de fichiers", "Could not read file information": "Impossible de lire les informations du fichier", "File mode saved": "Droits du fichier sauvegard\u00e9s", "Could not load directory": "Impossible de charger le r\u00e9pertoire", "Delete selected items?": "Supprimer les \u00e9l\u00e9ments s\u00e9lectionn\u00e9s ?", "Could not create file": "Impossible de cr\u00e9er le fichier", "Could not create directory": "Impossible de cr\u00e9er le r\u00e9pertoire", "Uploaded": "Transf\u00e9r\u00e9"}