{"": "", "< Back": "", "Access": "Acceso", "All": "Todo", "Apply": "Aplicar", "Cancel": "Cancelar", "Change permissions": "Modificar permisos", "Clipboard": "Portapapeles", "Close": "Cerrar", "Copy": "Copiar", "Create": "Crear", "Cut": "Cortar", "DIRECTORY": "DIRECTORIO", "Delete": "Borrar", "Directory name": "Nombre del directorio", "EXECUTE": "EJECUTAR", "Edit in Notepad": "Editar en Bloc de Notas", "Extra": "Extra", "FILE": "Archivo", "File name": "Nombre de archivo", "Full path": "Ruta completa", "Group": "Grupo", "LINK": "ENLACE", "Mode": "Modo", "Modified": "Modificado", "Name": "Nombre", "New directory": "Nuevo directorio", "New file": "Nuevo archivo", "Owner": "Propietario", "Paste here": "Pegar aqu\u00ed", "Permission bits": "Permisos en bits", "READ": "LEER", "Remove": "Eliminar", "Remove all items": "Eliminar todos los art\u00edculos", "Root directory": "", "Show in Notepad": "", "Size": "Tama\u00f1o", "Tab": "Pesta\u00f1a", "Type": "Tipo", "Upload": "Subir", "Uploading ...": "", "User": "Usuario", "WRITE": "ESCRIBIR", "items selected": "elementos seleccionados", "File Manager": "Gestor de archivos", "Could not read file information": "", "File mode saved": "", "Could not load directory": "", "Delete selected items?": "", "Could not create file": "", "Could not create directory": "", "Uploaded": ""}