{"": "", "< Back": "", "Access": "Acesso", "All": "Todos", "Apply": "Aplicar", "Cancel": "Cancelar", "Change permissions": "Alterar permiss\u00f5es", "Clipboard": "\u00c1rea de transfer\u00eancia", "Close": "Fechar", "Copy": "Copiar", "Create": "Criar", "Cut": "Cortar", "DIRECTORY": "DIRET\u00d3RIO", "Delete": "Eliminar", "Directory name": "Nome do diret\u00f3rio", "EXECUTE": "EXECUTAR", "Edit in Notepad": "Editar no bloco de notas", "Extra": "Extra", "FILE": "ARQUIVO", "File name": "Nome do ficheiro", "Full path": "Caminho completo", "Group": "Grupo", "LINK": "LINK", "Mode": "Modo", "Modified": "Modified", "Name": "Nome", "New directory": "Novo diret\u00f3rio", "New file": "Novo ficheiro", "Owner": "Propriet\u00e1rio", "Paste here": "Colar aqui", "Permission bits": "Bits de permiss\u00e3o", "READ": "LER", "Remove": "Remover", "Remove all items": "Remover todos os itens", "Root directory": "", "Show in Notepad": "", "Size": "Tamanho", "Tab": "Separador", "Type": "Tipo", "Upload": "Carregar (upload)", "Uploading ...": "", "User": "Utilizador", "WRITE": "ESCREVER", "items selected": "itens selecionados", "File Manager": "Gestor ficheiros", "Could not read file information": "", "File mode saved": "", "Could not load directory": "", "Delete selected items?": "", "Could not create file": "", "Could not create directory": "", "Uploaded": ""}