{"": "", "< Back": "", "Access": "Hozz\u00e1f\u00e9r\u00e9s", "All": "\u00d6sszes", "Apply": "Alkalmaz", "Cancel": "M\u00e9gse", "Change permissions": "Enged\u00e9lyek m\u00f3dos\u00edt\u00e1sa", "Clipboard": "V\u00e1g\u00f3lap", "Close": "Bez\u00e1r\u00e1s", "Copy": "M\u00e1sol\u00e1s", "Create": "L\u00e9trehoz\u00e1s", "Cut": "Kiv\u00e1g\u00e1s", "DIRECTORY": "K\u00d6NYVT\u00c1R", "Delete": "T\u00f6rl\u00e9s", "Directory name": "K\u00f6nyvt\u00e1rn\u00e9v", "EXECUTE": "V\u00c9GREHAJT\u00c1S", "Edit in Notepad": "Megtekint\u00e9s jegyzett\u00f6mbben", "Extra": "Extr\u00e1k", "FILE": "F\u00c1JL", "File name": "F\u00e1jln\u00e9v", "Full path": "Teljes el\u00e9r\u00e9si \u00fat", "Group": "Csoport", "LINK": "HIVATKOZ\u00c1S", "Mode": "M\u00f3d", "Modified": "M\u00f3dos\u00edtva", "Name": "N\u00e9v", "New directory": "\u00daj k\u00f6nyvt\u00e1r", "New file": "\u00daj f\u00e1jl", "Owner": "", "Paste here": "", "Permission bits": "", "READ": "", "Remove": "", "Remove all items": "", "Root directory": "", "Show in Notepad": "", "Size": "", "Tab": "", "Type": "", "Upload": "", "Uploading ...": "", "User": "", "WRITE": "", "items selected": "elem kijel\u00f6lve", "File Manager": "", "Could not read file information": "", "File mode saved": "", "Could not load directory": "", "Delete selected items?": "", "Could not create file": "", "Could not create directory": "", "Uploaded": ""}