{"": "", "< Back": "", "Access": "", "All": "Kaikki", "Apply": "Hyv\u00e4ksy", "Cancel": "Peruuta", "Change permissions": "", "Clipboard": "Leikep\u00f6yt\u00e4", "Close": "Sulje", "Copy": "Kopioi", "Create": "Luo", "Cut": "Leikkaa", "DIRECTORY": "HAKEMISTO", "Delete": "Poista", "Directory name": "Hakemiston nimi", "EXECUTE": "SUORITA", "Edit in Notepad": "Muokkaa Muistiossa", "Extra": "", "FILE": "TIEDOSTO", "File name": "Tiedostonimi", "Full path": "Koko polku", "Group": "Ryhm\u00e4", "LINK": "LINKKI", "Mode": "Tila", "Modified": "Muokattu", "Name": "Nimi", "New directory": "Uusi hakemisto", "New file": "Uusi tiedosto", "Owner": "Omistaja", "Paste here": "Liit\u00e4 t\u00e4h\u00e4n", "Permission bits": "", "READ": "LUE", "Remove": "Poista", "Remove all items": "Poista kaikki kohteet", "Root directory": "", "Show in Notepad": "", "Size": "Koko", "Tab": "", "Type": "", "Upload": "", "Uploading ...": "", "User": "", "WRITE": "", "items selected": "kohdetta valittu", "File Manager": "", "Could not read file information": "", "File mode saved": "", "Could not load directory": "", "Delete selected items?": "", "Could not create file": "", "Could not create directory": "", "Uploaded": ""}