{"": "", "< Back": "", "Access": "Toegang", "All": "Alle", "Apply": "Toepassen", "Cancel": "Annuleren", "Change permissions": "Machtigingen wijzigen", "Clipboard": "Klembord", "Close": "Sluiten", "Copy": "Kopi\u00ebren", "Create": "Maak nieuwe aan", "Cut": "Knippen", "DIRECTORY": "DIRECTORY", "Delete": "Verwijderen", "Directory name": "Mapnaam", "EXECUTE": "UITVOEREN", "Edit in Notepad": "Bewerken in Kladblok", "Extra": "Extra", "FILE": "BESTAND", "File name": "Bestandsnaam", "Full path": "Volledige pad", "Group": "Groep", "LINK": "KOPPELING", "Mode": "Modus", "Modified": "Aangepast", "Name": "Naam", "New directory": "Nieuwe locatie", "New file": "Nieuw Bestand", "Owner": "Eigenaar", "Paste here": "Plak hier", "Permission bits": "Permission bits", "READ": "LEZEN", "Remove": "Verwijderen", "Remove all items": "Alle items verwijderen", "Root directory": "", "Show in Notepad": "", "Size": "Grootte", "Tab": "Tabblad", "Type": "Type", "Upload": "Upload", "Uploading ...": "", "User": "Gebruiker", "WRITE": "SCHRIJVEN", "items selected": "geselecteerde items", "File Manager": "Bestandsbeheer", "Could not read file information": "", "File mode saved": "", "Could not load directory": "", "Delete selected items?": "", "Could not create file": "", "Could not create directory": "", "Uploaded": ""}