{"": "", "< Back": "", "Access": "Dost\u0119p", "All": "Wszyscy", "Apply": "Zastosuj", "Cancel": "Anuluj", "Change permissions": "Zmie\u0144 uprawnienia", "Clipboard": "Schowek", "Close": "Zamknij", "Copy": "Kopiuj", "Create": "Utw\u00f3rz", "Cut": "Wytnij", "DIRECTORY": "KATALOG", "Delete": "Usu\u0144", "Directory name": "Nazwa katalogu", "EXECUTE": "WYKONAJ", "Edit in Notepad": "Edytuj w notatniku", "Extra": "Dodatkowe", "FILE": "PLIK", "File name": "Nazwa pliku", "Full path": "Pe\u0142na \u015bcie\u017cka", "Group": "Grupa", "LINK": "\u0141\u0104CZE", "Mode": "Tryb", "Modified": "Zmodyfikowany", "Name": "Nazwa", "New directory": "Nowy Katalog", "New file": "Nowy plik", "Owner": "W\u0142a\u015bciciel", "Paste here": "Wklej tutaj", "Permission bits": "Bity uprawnie\u0144", "READ": "ODCZYT", "Remove": "Usu\u0144", "Remove all items": "Usu\u0144 wszystkie elementy", "Root directory": "", "Show in Notepad": "Poka\u017c w notatniku", "Size": "Rozmiar", "Tab": "Karta", "Type": "Typ", "Upload": "Prze\u015blij", "Uploading ...": "Przesy\u0142anie...", "User": "U\u017cytkownik", "WRITE": "ZAPISZ", "items selected": "wybrane elementy", "File Manager": "Mened\u017cer plik\u00f3w", "Could not read file information": "Nie mo\u017cna odczyta\u0107 informacji o pliku", "File mode saved": "Tryb pliku zapisany", "Could not load directory": "Nie mo\u017cna za\u0142adowa\u0107 katalogu", "Delete selected items?": "Usun\u0105\u0107 wybrane elementy?", "Could not create file": "Nie mo\u017cna utworzy\u0107 pliku", "Could not create directory": "Nie mo\u017cna utworzy\u0107 katalogu", "Uploaded": "Wys\u0142ane"}