{"": "", "< Back": "", "Access": "P\u0159\u00edstup", "All": "V\u0161ichni", "Apply": "Pou\u017e\u00edt", "Cancel": "Zru\u0161it", "Change permissions": "Zm\u011bnit opr\u00e1vn\u011bn\u00ed", "Clipboard": "Schr\u00e1nka", "Close": "Zav\u0159\u00edt", "Copy": "Kop\u00edrovat", "Create": "Vytvo\u0159it", "Cut": "Vyjmout", "DIRECTORY": "ADRES\u00c1\u0158", "Delete": "Odstranit", "Directory name": "Jm\u00e9no adres\u00e1\u0159e", "EXECUTE": "SPUSTIT", "Edit in Notepad": "Upravit v Pozn\u00e1mkov\u00e9m bloku", "Extra": "Nav\u00edc", "FILE": "SOUBOR", "File name": "N\u00e1zev souboru", "Full path": "\u00dapln\u00e1 cesta", "Group": "Skupina", "LINK": "ODKAZ", "Mode": "Re\u017eim", "Modified": "Upraveno", "Name": "Jm\u00e9no", "New directory": "Nov\u00e1 slo\u017eka", "New file": "Nov\u00fd soubor", "Owner": "Vlastn\u00edk", "Paste here": "Vlo\u017eit zde", "Permission bits": "Bity opr\u00e1vn\u011bn\u00ed", "READ": "\u010c\u00cdST", "Remove": "Odstranit", "Remove all items": "Odebrat v\u0161echny polo\u017eky", "Root directory": "", "Show in Notepad": "", "Size": "Velikost", "Tab": "Karta", "Type": "Typ", "Upload": "Nahr\u00e1t", "Uploading ...": "", "User": "U\u017eivatel", "WRITE": "Z\u00c1PIS", "items selected": "vybran\u00fdch polo\u017eek", "File Manager": "Spr\u00e1vce soubor\u016f", "Could not read file information": "", "File mode saved": "", "Could not load directory": "", "Delete selected items?": "", "Could not create file": "", "Could not create directory": "", "Uploaded": ""}